@@ -596,6 +596,10 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
           writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.LIGHT_SOURCE_COLOR, i, lightSourceColor);
           writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.LIGHT_SOURCE_DIAMETER, i, lightSourceDiameter);
         }
+        String [] lightSourceMaterialNames = light.getLightSourceMaterialNames();
+        if (lightSourceMaterialNames.length > 0) {
+          writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.LIGHT_SOURCE_MATERIAL_NAME, i, lightSourceMaterialNames);
+        }
       }
       if (piece.getElevation() > 0) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.ELEVATION, i, piece.getElevation());
@@ -608,6 +612,9 @@ public class FurnitureLibraryFileRecorder implements FurnitureLibraryRecorder {
       if (!"1 0 0 0 1 0 0 0 1".equals(modelRotationString)) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.MODEL_ROTATION, i, modelRotationString);
       }
+      if (piece.getModelFlags() != 0) {
+        writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.MODEL_FLAGS, i, piece.getModelFlags());
+      }
       if (piece.getStaircaseCutOutShape() != null) {
         writeProperty(writer, DefaultFurnitureCatalog.PropertyKey.STAIRCASE_CUT_OUT_SHAPE, i, piece.getStaircaseCutOutShape());
       }
